free
====

.. image:: https://img.shields.io/pypi/l/macos-free.svg
    :target: https://pypi.python.org/pypi/macos-free

.. image:: https://img.shields.io/pypi/v/macos-free.svg
    :target: https://pypi.python.org/pypi/macos-free

.. image:: https://img.shields.io/pypi/pyversions/macos-free.svg
    :target: https://pypi.python.org/pypi/macos-free

.. image:: https://img.shields.io/travis/cls1991/macos-free.svg
    :target: 

---------------

Memory usage for macos,  an alternative to free command.

☤ Installation
--------------

You can install "macos-free" via `pip`_ from `PyPI`_

::

	$ pip install macos-free
	
☤ Usage
-------

::

	$ free --help
	Usage: free [OPTIONS]

	Options:
	  -b, --bytes    show output in bytes
	  -k, --kilo     show output in kilobytes
	  -m, --mega     show output in megabytes
	  -g, --giga     show output in gigabytes
	  --tera         show output in terabytes
	  -h, --human    show human-readable output
	  --si           use powers of 1000 not 1024
	  -V, --version  output version information and exit
	  --help         Show this message and exit.





